<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page while offline.
 *
 * All the available variables are mirrored in html.tpl.php and page.tpl.php.
 * Some may be blank but they are provided for consistency.
 *
 * @see template_preprocess()
 * @see template_preprocess_maintenance_page()
 *
 * @ingroup themeable
 */
?>
<!doctype html>
<!--[if IE 9]> <html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>" class="no-js ie lt-ie10 ie9"> <![endif]-->
<!--[if gt IE 9]><!--> <html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>" class="no-js not-ie"> <!--<![endif]-->

<head>
  <title><?php print $head_title; ?></title>
  <meta name="viewport" content="width=device-width, initial-scale=1" />
  <?php print $head; ?>
  <?php print $styles; ?>
  <?php print $scripts; ?>
</head>

<body class="<?php print $classes; ?>" <?php print $attributes;?>>

  <?php // region: header ?>
  <header class="region r-header" id="header">
    <div class="inner">
      <?php if (!empty($logo)): ?>
        <div class="logo">
          <?php if (drupal_is_front_page()): ?>
            <h1 class="element-invisible"><?php print check_plain($site_name); ?></h1>
          <?php endif; ?>
          <a href="<?php print url('<front>'); ?>"><img src="<?php print $svg_logo; ?>" onerror="this.src='<?php print $logo; ?>'" alt="<?php print $site_name;?>"/></a>
        </div>
      <?php endif; ?>

      <?php if (!empty($site_slogan)): ?>
        <div class="slogan"><?php print $site_slogan; ?></div>
      <?php endif; ?>
    </div>
  </header>

  <div id="wrapper">
    <div class="l-page" id="page">
      <div class="region r-content" id="content">
        <div class="inner">

          <?php // page title ?>
          <?php print render($title_prefix); ?>
          <?php if ($title): ?>
            <h1><?php print $title; ?></h1>
          <?php endif; ?>
          <?php print render($title_suffix); ?>

          <?php // system: messages ?>
          <?php if ($html = render($messages)): ?>
            <div class="l-messages" id="messages"><?php print $html; ?></div>
          <?php endif; ?>

          <?php // region: content ?>
          <?php print $content; ?>

        </div><?php // .inner ?>
      </div><?php // #content ?>
    </div><?php // #page ?>
  </div><?php // #wrapper ?>

</body>
</html>
